pub enum GPUError {
Opencl3(ClError, Option<String>),
ProgramInfoNotAvailable(ClError),
DeviceInfoNotAvailable(ClError),
Cuda(CudaError),
DeviceNotFound,
KernelNotFound(String),
IO(Error),
UnsupportedVendor(String),
InvalidId(String),
Generic(String),
}Expand description
Error types of this library.
Variants
Opencl3(ClError, Option<String>)
Error from the underlying opencl3 library, e.g. a memory allocation failure.
ProgramInfoNotAvailable(ClError)
Error for OpenCL clGetProgramInfo() call failures.
DeviceInfoNotAvailable(ClError)
Error for OpenCL clGetDeviceInfo() call failures.
Cuda(CudaError)
Error from the underlying RustaCUDA library, e.g. a memory allocation failure.
DeviceNotFound
Error when a device cannot be found.
KernelNotFound(String)
Error when a kernel with the given name cannot be found.
IO(Error)
Error when standard I/O fails.
UnsupportedVendor(String)
Error when the device is from an unsupported vendor.
InvalidId(String)
Error when the string representation of a unique identifier (PCI-ID or UUID) cannot be parsed.
Generic(String)
Errors that rarely happen and don’t deserve their own error type.