Struct rust_gpu_tools::opencl::Buffer
source · pub struct Buffer<T> { /* private fields */ }Expand description
A Buffer to be used for sending and receiving data to/from the GPU.
pub struct Buffer<T> { /* private fields */ }A Buffer to be used for sending and receiving data to/from the GPU.